==> binnie-mods-1.11.2-2.1.0.8-sources.jar: binnie/extratrees/block/decor/BlockHedge.java <==
package binnie.extratrees.block.decor;

import javax.annotation.Nullable;
import java.util.List;

import net.minecraft.block.Block;
import net.minecraft.block.BlockFence;
import net.minecraft.block.BlockFenceGate;
import net.minecraft.block.material.Material;
import net.minecraft.block.state.IBlockState;
import net.minecraft.creativetab.CreativeTabs;
import net.minecraft.entity.Entity;
import net.minecraft.init.Blocks;
import net.minecraft.item.Item;
import net.minecraft.item.ItemStack;
import net.minecraft.util.EnumFacing;
import net.minecraft.util.NonNullList;
import net.minecraft.util.math.AxisAlignedBB;
import net.minecraft.util.math.BlockPos;
import net.minecraft.world.ColorizerFoliage;
import net.minecraft.world.IBlockAccess;
import net.minecraft.world.World;

import net.minecraftforge.fml.relauncher.Side;
import net.minecraftforge.fml.relauncher.SideOnly;

import forestry.api.arboriculture.EnumLeafType;
import forestry.api.core.Tabs;
import forestry.arboriculture.PluginArboriculture;
import forestry.core.blocks.IColoredBlock;

public class BlockHedge extends Block implements IBlockFence, IColoredBlock {
	public BlockHedge() {
		super(Material.field_151584_j);
		this.func_149647_a(Tabs.tabArboriculture);
		this.setRegistryName("hedge");
	}

	@SideOnly(Side.CLIENT)
	public static int getColor(int meta) {
		EnumLeafType type = EnumLeafType.values()[meta % 6];
		if (type == EnumLeafType.CONIFERS) {
			return ColorizerFoliage.func_77466_a();
		}
		final double d0 = 0.5;
		final double d2 = 1.0;
		return ColorizerFoliage.func_77470_a(d0, d2);
	}

	@Override
	public void func_185477_a(IBlockState state, World world, BlockPos pos, AxisAlignedBB entityBox, List<AxisAlignedBB> collidingBoxes, @Nullable Entity entityIn, boolean p_185477_7_) {
		final boolean connectNegZ = this.canConnectFenceTo(world, pos.func_177978_c());
		final boolean connectPosZ = this.canConnectFenceTo(world, pos.func_177968_d());
		final boolean connectNegX = this.canConnectFenceTo(world, pos.func_177976_e());
		final boolean connectPosX = this.canConnectFenceTo(world, pos.func_177974_f());
		float f = 0.25f;
		float f2 = 0.75f;
		float f3 = 0.25f;
		float f4 = 0.75f;
		if (connectNegZ) {
			f3 = 0.0f;
		}
		if (connectPosZ) {
			f4 = 1.0f;
		}
		if (connectNegZ || connectPosZ) {
			func_185492_a(pos, entityBox, collidingBoxes, new AxisAlignedBB(f, 0.0f, f3, f2, 1.5f, f4));
		}
		f3 = 0.25f;
		f4 = 0.75f;
		if (connectNegX) {
			f = 0.0f;
		}
		if (connectPosX) {
			f2 = 1.0f;
		}
		if (connectNegX || connectPosX || (!connectNegZ && !connectPosZ)) {
			func_185492_a(pos, entityBox, collidingBoxes, new AxisAlignedBB(f, 0.0f, f3, f2, 1.5f, f4));
		}
		if (connectNegZ) {
			f3 = 0.0f;
		}
		if (connectPosZ) {
			f4 = 1.0f;
		}
		func_185492_a(pos, entityBox, collidingBoxes, new AxisAlignedBB(f, 0.0f, f3, f2, 1.0f, f4));
	}

	@Override
	public AxisAlignedBB func_185496_a(IBlockState state, IBlockAccess world, BlockPos pos) {
		final boolean connectNegZ = this.canConnectFenceTo(world, pos.func_177978_c());
		final boolean connectPosZ = this.canConnectFenceTo(world, pos.func_177968_d());
		final boolean connectNegX = this.canConnectFenceTo(world, pos.func_177976_e());
		final boolean connectPosX = this.canConnectFenceTo(world, pos.func_177974_f());
		float f = 0.25f;
		float f2 = 0.75f;
		float f3 = 0.25f;
		float f4 = 0.75f;
		if (connectNegZ) {
			f3 = 0.0f;
		}
		if (connectPosZ) {
			f4 = 1.0f;
		}
		if (connectNegX) {
			f = 0.0f;
		}
		if (connectPosX) {
			f2 = 1.0f;
		}
		return new AxisAlignedBB(f, 0.0f, f3, f2, 1.0f, f4);
	}

	@Override
	public boolean func_149662_c(IBlockState state) {
		return false;
	}

	@Override
	public boolean func_149686_d(IBlockState state) {
		return false;
	}

	/*@Override
	public int getRenderType() {
		return ModuleBlocks.hedgeRenderID;
	}*/

	@Override
	public boolean func_176205_b(IBlockAccess worldIn, BlockPos pos) {
		return false;
	}

	public boolean canConnectFenceTo(IBlockAccess world, BlockPos pos) {
		IBlockState state = world.func_180495_p(pos);
		Block block = state.func_177230_c();
		return block == this || canConnectTo(world, pos) || block.isLeaves(state, world, pos) || (state.func_185904_a().func_76218_k() && state.func_185917_h() && state.func_185904_a() != Material.field_151572_C);
	}

	private boolean canConnectTo(IBlockAccess worldIn, BlockPos pos) {
		IBlockState state = worldIn.func_180495_p(pos);
		Block block = state.func_177230_c();
		if (PluginArboriculture.validFences.contains(block)) {
			return true;
		}

		if (block != Blocks.field_180401_cv) {
			Material blockMaterial = state.func_185904_a();
			if (block instanceof BlockFence || block instanceof BlockFenceGate || block instanceof IBlockFence) {
				return blockMaterial == this.field_149764_J;
			}
			if (blockMaterial.func_76218_k() && state.func_185917_h() && blockMaterial != Material.field_151572_C) {
				return true;
			}
		}
		return false;
	}

	@SideOnly(Side.CLIENT)
	@Override
	public boolean func_176225_a(IBlockState blockState, IBlockAccess blockAccess, BlockPos pos, EnumFacing side) {
		return true;
	}

	private EnumLeafType getType(int meta) {
		return EnumLeafType.values()[meta % 8];
	}

	/*@Override
	@SideOnly(Side.CLIENT)
	public IIcon getIcon(final int p_149691_1_, final int meta) {
		final ExtraTreeSpecies.LeafType type = this.getType(meta);
		return ForestryAPI.textureManager.getIcon(this.isFull(meta) ? type.plainUID : type.fancyUID);
	}*/

	private boolean isFull(final int meta) {
		return meta / 8 > 0;
	}

	@Override
	@SideOnly(Side.CLIENT)
	public void func_149666_a(final Item item, final CreativeTabs tab, final NonNullList<ItemStack> list) {
		for (int i = 0; i < 6; ++i) {
			for (int f = 0; f < 2; ++f) {
				list.add(new ItemStack(item, 1, i + f * 8));
			}
		}
	}

	@SideOnly(Side.CLIENT)
	@Override
	public int colorMultiplier(IBlockState state, @Nullable IBlockAccess world, @Nullable BlockPos pos, int tintIndex) {
		return getColor(func_176201_c(state));
	}
}

==> binnie-mods-1.12-2.2.0.3-sources.jar: binnie/extratrees/block/decor/BlockHedge.java <==
package binnie.extratrees.block.decor;

import javax.annotation.Nullable;
import java.util.List;

import net.minecraft.block.Block;
import net.minecraft.block.BlockFence;
import net.minecraft.block.BlockFenceGate;
import net.minecraft.block.material.Material;
import net.minecraft.block.state.IBlockState;
import net.minecraft.creativetab.CreativeTabs;
import net.minecraft.entity.Entity;
import net.minecraft.init.Blocks;
import net.minecraft.item.Item;
import net.minecraft.item.ItemStack;
import net.minecraft.util.EnumFacing;
import net.minecraft.util.NonNullList;
import net.minecraft.util.math.AxisAlignedBB;
import net.minecraft.util.math.BlockPos;
import net.minecraft.world.ColorizerFoliage;
import net.minecraft.world.IBlockAccess;
import net.minecraft.world.World;

import net.minecraftforge.fml.relauncher.Side;
import net.minecraftforge.fml.relauncher.SideOnly;

import forestry.api.arboriculture.EnumLeafType;
import forestry.api.core.Tabs;
import forestry.arboriculture.PluginArboriculture;
import forestry.core.blocks.IColoredBlock;

public class BlockHedge extends Block implements IBlockFence, IColoredBlock {
	public BlockHedge() {
		super(Material.field_151584_j);
		this.func_149647_a(Tabs.tabArboriculture);
		this.setRegistryName("hedge");
	}

	@SideOnly(Side.CLIENT)
	public static int getColor(int meta) {
		EnumLeafType type = EnumLeafType.values()[meta % 6];
		if (type == EnumLeafType.CONIFERS) {
			return ColorizerFoliage.func_77466_a();
		}
		final double d0 = 0.5;
		final double d2 = 1.0;
		return ColorizerFoliage.func_77470_a(d0, d2);
	}

	@Override
	public void func_185477_a(IBlockState state, World world, BlockPos pos, AxisAlignedBB entityBox, List<AxisAlignedBB> collidingBoxes, @Nullable Entity entityIn, boolean p_185477_7_) {
		final boolean connectNegZ = this.canConnectFenceTo(world, pos.func_177978_c());
		final boolean connectPosZ = this.canConnectFenceTo(world, pos.func_177968_d());
		final boolean connectNegX = this.canConnectFenceTo(world, pos.func_177976_e());
		final boolean connectPosX = this.canConnectFenceTo(world, pos.func_177974_f());
		float f = 0.25f;
		float f2 = 0.75f;
		float f3 = 0.25f;
		float f4 = 0.75f;
		if (connectNegZ) {
			f3 = 0.0f;
		}
		if (connectPosZ) {
			f4 = 1.0f;
		}
		if (connectNegZ || connectPosZ) {
			func_185492_a(pos, entityBox, collidingBoxes, new AxisAlignedBB(f, 0.0f, f3, f2, 1.5f, f4));
		}
		f3 = 0.25f;
		f4 = 0.75f;
		if (connectNegX) {
			f = 0.0f;
		}
		if (connectPosX) {
			f2 = 1.0f;
		}
		if (connectNegX || connectPosX || (!connectNegZ && !connectPosZ)) {
			func_185492_a(pos, entityBox, collidingBoxes, new AxisAlignedBB(f, 0.0f, f3, f2, 1.5f, f4));
		}
		if (connectNegZ) {
			f3 = 0.0f;
		}
		if (connectPosZ) {
			f4 = 1.0f;
		}
		func_185492_a(pos, entityBox, collidingBoxes, new AxisAlignedBB(f, 0.0f, f3, f2, 1.0f, f4));
	}

	@Override
	public AxisAlignedBB func_185496_a(IBlockState state, IBlockAccess world, BlockPos pos) {
		final boolean connectNegZ = this.canConnectFenceTo(world, pos.func_177978_c());
		final boolean connectPosZ = this.canConnectFenceTo(world, pos.func_177968_d());
		final boolean connectNegX = this.canConnectFenceTo(world, pos.func_177976_e());
		final boolean connectPosX = this.canConnectFenceTo(world, pos.func_177974_f());
		float f = 0.25f;
		float f2 = 0.75f;
		float f3 = 0.25f;
		float f4 = 0.75f;
		if (connectNegZ) {
			f3 = 0.0f;
		}
		if (connectPosZ) {
			f4 = 1.0f;
		}
		if (connectNegX) {
			f = 0.0f;
		}
		if (connectPosX) {
			f2 = 1.0f;
		}
		return new AxisAlignedBB(f, 0.0f, f3, f2, 1.0f, f4);
	}

	@Override
	public boolean func_149662_c(IBlockState state) {
		return false;
	}

	@Override
	public boolean func_149686_d(IBlockState state) {
		return false;
	}

	/*@Override
	public int getRenderType() {
		return ModuleBlocks.hedgeRenderID;
	}*/

	@Override
	public boolean func_176205_b(IBlockAccess worldIn, BlockPos pos) {
		return false;
	}

	public boolean canConnectFenceTo(IBlockAccess world, BlockPos pos) {
		IBlockState state = world.func_180495_p(pos);
		Block block = state.func_177230_c();
		return block == this || canConnectTo(world, pos) || block.isLeaves(state, world, pos) || (state.func_185904_a().func_76218_k() && state.func_185917_h() && state.func_185904_a() != Material.field_151572_C);
	}

	private boolean canConnectTo(IBlockAccess worldIn, BlockPos pos) {
		IBlockState state = worldIn.func_180495_p(pos);
		Block block = state.func_177230_c();
		if (PluginArboriculture.validFences.contains(block)) {
			return true;
		}

		if (block != Blocks.field_180401_cv) {
			Material blockMaterial = state.func_185904_a();
			if (block instanceof BlockFence || block instanceof BlockFenceGate || block instanceof IBlockFence) {
				return blockMaterial == this.field_149764_J;
			}
			if (blockMaterial.func_76218_k() && state.func_185917_h() && blockMaterial != Material.field_151572_C) {
				return true;
			}
		}
		return false;
	}

	@SideOnly(Side.CLIENT)
	@Override
	public boolean func_176225_a(IBlockState blockState, IBlockAccess blockAccess, BlockPos pos, EnumFacing side) {
		return true;
	}

	private EnumLeafType getType(int meta) {
		return EnumLeafType.values()[meta % 8];
	}

	/*@Override
	@SideOnly(Side.CLIENT)
	public IIcon getIcon(final int p_149691_1_, final int meta) {
		final ExtraTreeSpecies.LeafType type = this.getType(meta);
		return ForestryAPI.textureManager.getIcon(this.isFull(meta) ? type.plainUID : type.fancyUID);
	}*/

	private boolean isFull(final int meta) {
		return meta / 8 > 0;
	}

	@Override
	public void func_149666_a(CreativeTabs tab, NonNullList<ItemStack> list) {
		for (int i = 0; i < 6; ++i) {
			for (int f = 0; f < 2; ++f) {
				list.add(new ItemStack(this, 1, i + f * 8));
			}
		}
	}

	@SideOnly(Side.CLIENT)
	@Override
	public int colorMultiplier(IBlockState state, @Nullable IBlockAccess world, @Nullable BlockPos pos, int tintIndex) {
		return getColor(func_176201_c(state));
	}
}
